summaryrefslogtreecommitdiff
path: root/numpy/tests
diff options
context:
space:
mode:
authorBas van Beek <b.f.van.beek@vu.nl>2020-08-19 20:51:09 +0200
committerBas van Beek <b.f.van.beek@vu.nl>2020-08-19 20:51:09 +0200
commit4af8fd39bfa4a30e9d26e8021b42ffadf1f99398 (patch)
tree95042fef7a12f1e96916f8eef8e8c86be34a690f /numpy/tests
parent160a782381d2f723b0f1d836503e13eedeaaf7aa (diff)
downloadnumpy-4af8fd39bfa4a30e9d26e8021b42ffadf1f99398.tar.gz
ENH: Replace module-level `__getattr__` with explicitly defined objects
Diffstat (limited to 'numpy/tests')
-rw-r--r--numpy/tests/typing/fail/modules.py3
-rw-r--r--numpy/tests/typing/reveal/modules.py4
2 files changed, 5 insertions, 2 deletions
diff --git a/numpy/tests/typing/fail/modules.py b/numpy/tests/typing/fail/modules.py
new file mode 100644
index 000000000..e7ffe8920
--- /dev/null
+++ b/numpy/tests/typing/fail/modules.py
@@ -0,0 +1,3 @@
+import numpy as np
+
+np.testing.bob # E: Module has no attribute
diff --git a/numpy/tests/typing/reveal/modules.py b/numpy/tests/typing/reveal/modules.py
index 736aae10c..16709496b 100644
--- a/numpy/tests/typing/reveal/modules.py
+++ b/numpy/tests/typing/reveal/modules.py
@@ -18,5 +18,5 @@ reveal_type(np.rec) # E: ModuleType
reveal_type(np.testing) # E: ModuleType
reveal_type(np.version) # E: ModuleType
-# TODO: Remove when annotations have been added to `np.linalg.norm`
-reveal_type(np.linalg.norm) # E: Any
+# TODO: Remove when annotations have been added to `np.testing.assert_equal`
+reveal_type(np.testing.assert_equal) # E: Any